@@ -13,6 +13,7 @@ Usage::
         CompositeAlarmExistsWaiter,
         DescribeAlarmHistoryPaginator,
         DescribeAlarmsPaginator,
+        DescribeAnomalyDetectorsPaginator,
         GetMetricDataPaginator,
         ListDashboardsPaginator,
         ListMetricsPaginator,
@@ -29,6 +30,7 @@ Usage::
 
     describe_alarm_history_paginator: DescribeAlarmHistoryPaginator = client.get_paginator("describe_alarm_history")
     describe_alarms_paginator: DescribeAlarmsPaginator = client.get_paginator("describe_alarms")
+    describe_anomaly_detectors_paginator: DescribeAnomalyDetectorsPaginator = client.get_paginator("describe_anomaly_detectors")
     get_metric_data_paginator: GetMetricDataPaginator = client.get_paginator("get_metric_data")
     list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
     list_metrics_paginator: ListMetricsPaginator = client.get_paginator("list_metrics")
@@ -38,6 +40,7 @@ from .client import CloudWatchClient
 from .paginator import (
     DescribeAlarmHistoryPaginator,
     DescribeAlarmsPaginator,
+    DescribeAnomalyDetectorsPaginator,
     GetMetricDataPaginator,
     ListDashboardsPaginator,
     ListMetricsPaginator,
@@ -59,6 +62,7 @@ __all__ = (
     "CompositeAlarmExistsWaiter",
     "DescribeAlarmHistoryPaginator",
     "DescribeAlarmsPaginator",
+    "DescribeAnomalyDetectorsPaginator",
     "GetMetricDataPaginator",
     "ListDashboardsPaginator",
     "ListMetricsPaginator",
