@@ -29,6 +29,7 @@ __all__ = (
     "CompositeAlarmExistsWaiterName",
     "DescribeAlarmHistoryPaginatorName",
     "DescribeAlarmsPaginatorName",
+    "DescribeAnomalyDetectorsPaginatorName",
     "GetMetricDataPaginatorName",
     "HistoryItemTypeType",
     "ListDashboardsPaginatorName",
@@ -66,6 +67,7 @@ ComparisonOperatorType = Literal[
 CompositeAlarmExistsWaiterName = Literal["composite_alarm_exists"]
 DescribeAlarmHistoryPaginatorName = Literal["describe_alarm_history"]
 DescribeAlarmsPaginatorName = Literal["describe_alarms"]
+DescribeAnomalyDetectorsPaginatorName = Literal["describe_anomaly_detectors"]
 GetMetricDataPaginatorName = Literal["get_metric_data"]
 HistoryItemTypeType = Literal["Action", "ConfigurationUpdate", "StateUpdate"]
 ListDashboardsPaginatorName = Literal["list_dashboards"]
@@ -136,6 +138,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -335,6 +338,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -434,6 +438,7 @@ ResourceServiceName = Literal[
 PaginatorName = Literal[
     "describe_alarm_history",
     "describe_alarms",
+    "describe_anomaly_detectors",
     "get_metric_data",
     "list_dashboards",
     "list_metrics",
