@@ -12,6 +12,7 @@ Usage::
     from mypy_boto3_cloudwatch.paginator import (
         DescribeAlarmHistoryPaginator,
         DescribeAlarmsPaginator,
+        DescribeAnomalyDetectorsPaginator,
         GetMetricDataPaginator,
         ListDashboardsPaginator,
         ListMetricsPaginator,
@@ -22,6 +23,7 @@ Usage::
 
     describe_alarm_history_paginator: DescribeAlarmHistoryPaginator = client.get_paginator("describe_alarm_history")
     describe_alarms_paginator: DescribeAlarmsPaginator = client.get_paginator("describe_alarms")
+    describe_anomaly_detectors_paginator: DescribeAnomalyDetectorsPaginator = client.get_paginator("describe_anomaly_detectors")
     get_metric_data_paginator: GetMetricDataPaginator = client.get_paginator("get_metric_data")
     list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
     list_metrics_paginator: ListMetricsPaginator = client.get_paginator("list_metrics")
@@ -33,11 +35,19 @@ from typing import Generic, Iterator, Sequence, TypeVar, Union
 
 from botocore.paginate import PageIterator, Paginator
 
-from .literals import AlarmTypeType, HistoryItemTypeType, ScanByType, StateValueType
+from .literals import (
+    AlarmTypeType,
+    AnomalyDetectorTypeType,
+    HistoryItemTypeType,
+    ScanByType,
+    StateValueType,
+)
 from .type_defs import (
     DescribeAlarmHistoryOutputTypeDef,
     DescribeAlarmsOutputTypeDef,
+    DescribeAnomalyDetectorsOutputTypeDef,
     DimensionFilterTypeDef,
+    DimensionTypeDef,
     GetMetricDataOutputTypeDef,
     LabelOptionsTypeDef,
     ListDashboardsOutputTypeDef,
@@ -55,6 +65,7 @@ else:
 __all__ = (
     "DescribeAlarmHistoryPaginator",
     "DescribeAlarmsPaginator",
+    "DescribeAnomalyDetectorsPaginator",
     "GetMetricDataPaginator",
     "ListDashboardsPaginator",
     "ListMetricsPaginator",
@@ -118,6 +129,27 @@ class DescribeAlarmsPaginator(Paginator):
         """
 
 
+class DescribeAnomalyDetectorsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAnomalyDetectors)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators/#describeanomalydetectorspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        Namespace: str = ...,
+        MetricName: str = ...,
+        Dimensions: Sequence[DimensionTypeDef] = ...,
+        AnomalyDetectorTypes: Sequence[AnomalyDetectorTypeType] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DescribeAnomalyDetectorsOutputTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAnomalyDetectors.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators/#describeanomalydetectorspaginator)
+        """
+
+
 class GetMetricDataPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
